import argparse
import sys

from .core import create_from_tree


def main() -> None:
    parser = argparse.ArgumentParser(
        prog="tree2repo",
        description="Create a repo structure from a pasted tree."
    )
    parser.add_argument(
        "--root",
        default=".",
        help="Directory where the structure will be created (default: current directory)."
    )
    parser.add_argument(
        "--respect-root",
        action="store_true",
        help="Create the first top-level directory from the tree as well."
    )

    args = parser.parse_args()
    tree_text = sys.stdin.read()

    create_from_tree(
        tree_text=tree_text,
        root=args.root,
        ignore_root_label=not args.respect_root,
    )


if __name__ == "__main__":
    main()



import shutil
from pathlib import Path

from tree2repo import create_from_tree


def test_create_from_tree(tmp_path: Path) -> None:
    tree = """project-root/
  src/
    package/
      __init__.py
  README.md
"""
    root = tmp_path / "work"
    root.mkdir()
    create_from_tree(tree, root=str(root))

    assert (root / "src" / "package" / "__init__.py").exists()
    assert (root / "README.md").exists()

    shutil.rmtree(root)



from pathlib import Path


def create_from_tree(tree_text: str, root: str = ".", ignore_root_label: bool = True) -> None:
    root_path = Path(root).resolve()
    stack = [(-1, root_path)]
    first_dir_line_skipped = False

    for raw_line in tree_text.splitlines():
        line = raw_line.rstrip("\n\r")
        if not line.strip():
            continue

        indent = len(line) - len(line.lstrip(" "))
        name = line.strip()

        if name.endswith("/"):
            is_dir = True
            name = name[:-1]
        else:
            is_dir = False

        if ignore_root_label and is_dir and indent == 0 and not first_dir_line_skipped:
            first_dir_line_skipped = True
            continue

        while stack and indent <= stack[-1][0]:
            stack.pop()

        parent = stack[-1][1] if stack else root_path
        path = parent / name

        if is_dir:
            path.mkdir(parents=True, exist_ok=True)
            stack.append((indent, path))
        else:
            path.parent.mkdir(parents=True, exist_ok=True)
            if not path.exists():
                path.touch()
